<?php
$open_pages_template_dir = get_template_directory();
$open_pages_template_dir_uri = get_template_directory_uri();


/*-------------------------------------------------------------------------------------------*/
/* Set up SkyThemes Designer */
/*-------------------------------------------------------------------------------------------*/
include( $open_pages_template_dir . '/skythemes_designer/skythemes_designer.php' );


/*-------------------------------------------------------------------------------------------*/
/* Plugins */
/*-------------------------------------------------------------------------------------------*/
include( $open_pages_template_dir . '/tgm-plugin-activation/settings.php' );


/*-------------------------------------------------------------------------------------------*/
/* Set up the Theme */
/*-------------------------------------------------------------------------------------------*/
add_action( 'after_setup_theme', 'open_pages_setup' );

function open_pages_setup() {
	add_theme_support('skythemes-designer');
	
	/* Feed Links */
	add_theme_support( 'automatic-feed-links' );
	
	/* Set up the translation */
	load_theme_textdomain( 'open-pages', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );
	
	/* Add Menu */
	register_nav_menus(array(
		'Header' => __('Header Navigation', 'open-pages')
	));
	
	/* Featured Images */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 940, 300, true );
	
	add_image_size( 'small-feature', 540 );
	add_image_size( 'large-feature', 940, 300, true );
	
	/* Post Formats */
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio' ) );
	
	/* Content Width */
	if ( ! isset( $content_width ) ) $content_width = 940;
}


/*-------------------------------------------------------------------------------------------*/
/* Site Title */
/*-------------------------------------------------------------------------------------------*/
add_filter( 'wp_title', 'open_pages_wp_title' );

function open_pages_wp_title($title) {
	global $page, $paged;
	
	$filtered_title = $title . get_bloginfo( 'name' );
	
	$site_description = get_bloginfo( 'description', 'display' );
	
	if ( $site_description && ( is_home() || is_front_page() ) )
		$filtered_title = $filtered_title . " | $site_description";
	
	if ( $paged >= 2 || $page >= 2 )
		$filtered_title = $filtered_title . ' | ' . sprintf( 'Page %s', max( $paged, $page ) );

	return $filtered_title;
}


/*-------------------------------------------------------------------------------------------*/
/* The Subtitle */
/*-------------------------------------------------------------------------------------------*/
function open_pages_the_subtitle() {
	global $post;
	
	$subtitle = get_post_meta($post->ID, '_subtitle', true);
	
	return apply_filters('open_pages_the_subtitle', $subtitle);
}


/*-------------------------------------------------------------------------------------------*/
/* Styles */
/*-------------------------------------------------------------------------------------------*/
add_action('wp_enqueue_scripts', 'open_pages_stylesheets');

function open_pages_stylesheets() {
	global $open_pages_template_dir_uri, $sd_template_name, $sd_template_id;
	
	$dev = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? true : false;
	
	if ( $dev == true ) {
		wp_enqueue_style( 'open-pages-reset', $open_pages_template_dir_uri . '/style/reset.css' );
		wp_enqueue_style( 'open-pages-tables', $open_pages_template_dir_uri . '/style/tables.css' );
		wp_enqueue_style( 'open-pages-forms', $open_pages_template_dir_uri . '/style/forms.css' );

		wp_enqueue_style( 'open-pages-style', $open_pages_template_dir_uri . '/style/style.css' );
		wp_enqueue_style( 'open-pages-comments', $open_pages_template_dir_uri . '/style/comments.css' );
		wp_enqueue_style( 'open-pages-menu', $open_pages_template_dir_uri . '/style/menu.css' );
		wp_enqueue_style( 'open-pages-type', $open_pages_template_dir_uri . '/style/type.css' );
		wp_enqueue_style( 'open-pages-colour', $open_pages_template_dir_uri . '/style/colour.css' );

		wp_enqueue_style( 'open-pages-classes', $open_pages_template_dir_uri . '/style/classes.css' );
		wp_enqueue_style( 'open-pages-buttons', $open_pages_template_dir_uri . '/style/buttons.css' );
		wp_enqueue_style( 'open-pages-blocks', $open_pages_template_dir_uri . '/style/blocks.css' );

		wp_enqueue_style( 'open-pages-magnific-popup', $open_pages_template_dir_uri . '/js/magnific-popup/magnific-popup.css' );
	}
	else {
		wp_enqueue_style( 'open-pages-merged-styles', $open_pages_template_dir_uri . '/style/style_merged_2.min.css' );
	}
	
	if ( ! defined('DESIGNER_INSTALLED') ) {
		wp_enqueue_style( 'open-pages-sans-designer', $open_pages_template_dir_uri . '/skythemes_designer/not_installed/style.css' );

		$theme_settings = get_option('open_pages_settings');
		
		if ( ! $theme_settings['scheme'] || $theme_settings['scheme'] == 'By the Fire' ) :
		    wp_enqueue_style( 'open-pages-scheme', $open_pages_template_dir_uri . SD_COLOUR_THEME_SCHEMES_PATH . '/By-the-Fire_min.css' );
        elseif ( $theme_settings['scheme'] == 'At Sea' ) :
		    wp_enqueue_style( 'open-pages-scheme', $open_pages_template_dir_uri . SD_COLOUR_THEME_SCHEMES_PATH . '/At-Sea_min.css' );
        elseif ( $theme_settings['scheme'] == 'Under a Tree' ) :
		    wp_enqueue_style( 'open-pages-scheme', $open_pages_template_dir_uri . SD_COLOUR_THEME_SCHEMES_PATH . '/Under-a-Tree_min.css' );
        endif;
        
		if ( ! $theme_settings['styleset'] || $theme_settings['styleset'] == 'Source' ) :
            wp_enqueue_style( 'open-pages-styleset', $open_pages_template_dir_uri . SD_TYPE_THEME_STYLESETS_PATH . '/Source_min.css' );
        	wp_enqueue_style( 'open-pages-Arvo', 'http://fonts.googleapis.com/css?family=Arvo' );
        	wp_enqueue_style( 'open-pages-Source', 'http://fonts.googleapis.com/css?family=Source+Sans+Pro:200,400,900' );
		elseif ( $theme_settings['styleset'] == 'Josefin' ) :
		    wp_enqueue_style( 'open-pages-styleset', $open_pages_template_dir_uri . SD_TYPE_THEME_STYLESETS_PATH . '/Josefin_min.css' );
			wp_enqueue_style( 'open-pages-Arvo', 'http://fonts.googleapis.com/css?family=Arvo' );
			wp_enqueue_style( 'open-pages-Josefin', 'http://fonts.googleapis.com/css?family=Josefin+Slab' );
		elseif ( $theme_settings['styleset'] == 'Julius' ) :
		    wp_enqueue_style( 'open-pages-styleset', $open_pages_template_dir_uri . SD_TYPE_THEME_STYLESETS_PATH . '/Julius_min.css' );
			wp_enqueue_style( 'open-pages-Arvo', 'http://fonts.googleapis.com/css?family=Arvo' );
			wp_enqueue_style( 'open-pages-Julius', 'http://fonts.googleapis.com/css?family=Julius+Sans+One' );
		elseif ( $theme_settings['styleset'] == 'Montez' ) :
		    wp_enqueue_style( 'open-pages-styleset', $open_pages_template_dir_uri . SD_TYPE_THEME_STYLESETS_PATH . '/Montez_min.css' );
			wp_enqueue_style( 'open-pages-Arvo', 'http://fonts.googleapis.com/css?family=Arvo' );
			wp_enqueue_style( 'open-pages-Montez', 'http://fonts.googleapis.com/css?family=Montez' );
		endif;
	}
}

add_action('wp_head', 'open_pages_designer_stylesheets');

function open_pages_designer_stylesheets() {
	global $open_pages_template_dir_uri, $sd_template_name, $sd_template_id;

	if ( defined('DESIGNER_INSTALLED') ) {
		sd_layout_css('global');
		sd_layout_css('template');
		
		SkyThemesDesignerType::type_styleset_css();
		SkyThemesDesignerType::typekit();
		SkyThemesDesignerType::google_web_fonts();
		
		$DesignerColour = new SkyThemesDesignerColour();
		$DesignerColour->colour_scheme_css();

		// @font-face fonts
		$fonts_available = array(
			// sans-serif
			'Source Sans Pro' => 'http://fonts.googleapis.com/css?family=Source+Sans+Pro:200,400,900',
			'Julius Sans One' => 'http://fonts.googleapis.com/css?family=Julius+Sans+One',
			'Josefin Sans' => 'http://fonts.googleapis.com/css?family=Josefin+Sans',
			
			// serif
			'Arvo' => 'http://fonts.googleapis.com/css?family=Arvo',
			'Josefin Slab' => 'http://fonts.googleapis.com/css?family=Josefin+Slab',
			'Abril Fatface' => 'http://fonts.googleapis.com/css?family=Abril+Fatface',
			
			// script
			'Montez' => 'http://fonts.googleapis.com/css?family=Montez',
			'Berkshire Swash' => 'http://fonts.googleapis.com/css?family=Berkshire+Swash'
		);
		
		if ( defined('DESIGNER_MODE') ) {
			// load all the @font-face stylesheets in Designer mode
			foreach ( $fonts_available as $font => $url ) {
				$font_dash = str_replace(' ', '-', $font);

				wp_enqueue_style( 'open-pages-' . $font_dash, $url );
			}
		}
		else {
			$fonts = SkyThemesDesignerType::get_fonts_used($sd_template_id);
			
			if ( is_array($fonts) ) {
				foreach ( $fonts as $font ) {
					$font_dash = str_replace(' ', '-', $font);

					wp_enqueue_style( 'open-pages-' . $font_dash, $fonts_available[$font] );
				}
			}
		}
	}
	else {

	}
}


/*-------------------------------------------------------------------------------------------*/
/* Scripts */
/*-------------------------------------------------------------------------------------------*/
add_action('wp_enqueue_scripts', 'open_pages_enqueue_scripts');

function open_pages_enqueue_scripts() {
	global $open_pages_template_dir_uri;
	
	wp_register_script(
		'bigTarget',
		$open_pages_template_dir_uri . '/js/bigTarget.js',
		array('jquery'),
		'1.0.1'
	);
	
	wp_register_script(
		'magnific-popup',
		$open_pages_template_dir_uri . '/js/magnific-popup/jquery.magnific-popup.min.js',
		array('jquery'),
		'0.9.6'
	);
	
	wp_register_script(
		'theme_js',
		$open_pages_template_dir_uri . '/js/script.js',
		array('jquery', 'bigTarget'),
		'1.0'
	);
	
	wp_enqueue_script('bigTarget');
	wp_enqueue_script('magnific-popup');
	wp_enqueue_script('theme_js');
}

add_action('wp_footer', 'open_pages_footer_scripts');

function open_pages_footer_scripts() {
	?>
	<script type="text/javascript">
		(function() {
			var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
			po.src = 'https://apis.google.com/js/plusone.js';
			var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
		})();
	</script>

	<div id="fb-root"></div>
	<script>(function(d, s, id) {
	  var js, fjs = d.getElementsByTagName(s)[0];
	  if (d.getElementById(id)) return;
	  js = d.createElement(s); js.id = id;
	  js.src = "//connect.facebook.net/en_US/all.js#xfbml=1";
	  fjs.parentNode.insertBefore(js, fjs);
	}(document, 'script', 'facebook-jssdk'));</script>
	<?php
}


/*-------------------------------------------------------------------------------------------*/
/* Subtitle */
/*-------------------------------------------------------------------------------------------*/
add_action( 'add_meta_boxes', 'add_open_pages_subtitle_metabox' );

add_action('edit_post', 'open_pages_subtitle_save');
add_action('save_post', 'open_pages_subtitle_save');
add_action('publish_post', 'open_pages_subtitle_save');
add_action('edit_page_form', 'open_pages_subtitle_save');

add_action( "admin_head-post.php", 'open_pages_admin_post_head' );
add_action( "admin_head-post-new.php", 'open_pages_admin_post_head' );

function add_open_pages_subtitle_metabox() {
	add_meta_box('subtitle', __('Subtitle', 'open-pages'), 'open_pages_subtitle', 'post', 'normal', 'high');
	add_meta_box('subtitle', __('Subtitle', 'open-pages'), 'open_pages_subtitle', 'page', 'normal', 'high');
}

function open_pages_subtitle() {
	global $post;
 
	wp_nonce_field( plugin_basename( __FILE__ ), 'open_pages_subtitle_noncename' );
 
	$subtitle = get_post_meta($post->ID, '_subtitle', true);
	?>
	
	<input type="text" name="_subtitle" value="<?php echo $subtitle; ?>" class="widefat" />
	<?php
}

function open_pages_subtitle_save($post_id) {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;

	if ( !wp_verify_nonce( $_POST['open_pages_subtitle_noncename'], plugin_basename( __FILE__ ) ) )
		return;
	
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return;
	}
	else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return;
	}
	
	update_post_meta( $post_id, '_subtitle', $_POST['_subtitle'] );
}

function open_pages_admin_post_head() {
  ?>
	<script type="text/javascript">
	jQuery(function($) {
		$('#subtitle').appendTo('#titlewrap');		
	});
	</script>
	
	<style type="text/css">
	#subtitle {
	position: relative;
	left: 1px;
	margin: 10px 0 30px;
	padding: 0;
	border: none;
	background: none
	}
	
	#subtitle .handlediv {
	display: none
	}
	
	#subtitle .inside {
	display: block;
	padding: 0;
	}
	
	#subtitle h3 {
	border: 0;
	background: none;
	cursor: default
	}
	
	#subtitle input {
	padding: 3px 8px;
	font-size: 1.7em;
	}
	</style>
	<?php
}


/*-------------------------------------------------------------------------------------------*/
/* Theme Options */
/*-------------------------------------------------------------------------------------------*/
if ( is_admin() && ! defined('DESIGNER_INSTALLED') ) {
    add_action('admin_menu', 'open_pages_settings_page');
    add_action('admin_init', 'open_pages_settings');
}

function open_pages_settings_page() {
    $theme_settings_page = add_theme_page( __( 'Theme Styles', 'open-pages' ), __( 'Theme Styles', 'open-pages' ), 'edit_theme_options', 'open_pages_settings', 'open_pages_settings_page_output');
}

function open_pages_settings_page_output() { ?>
	<div class="wrap">
		<h2><?php _e('Theme Settings', 'open-pages') ?></h2>
		
		<form method="post" action="options.php">
			<?php settings_fields('open_pages_settings'); ?>  
            <?php do_settings_sections('open_pages_settings'); ?>             
            <?php submit_button(); ?>
		</form>	
	</div>
	
	<?php
}

function open_pages_settings() {
	$theme_settings = get_option('open_pages_settings');

	if ( $theme_settings == false || $theme_settings == "" ) {
		$theme_settings = array(
			"scheme" => 'By the Fire',
			"styleset" => 'Source'
		);

		update_option( 'open_pages_settings', $theme_settings);
	}

	add_settings_section(  
		'open_pages_settings_styles',
		__( 'Styles', 'open-pages' ),
		'open_pages_settings_styles_output',
		'open_pages_settings'
	);

	add_settings_field(
		'scheme',
		__( 'Colour Scheme', 'open-pages' ),
		'open_pages_settings_scheme',
		'open_pages_settings',
		'open_pages_settings_styles'
	);

	add_settings_field(
		'styleset',
		__( 'Font Styleset', 'open-pages' ),
		'open_pages_settings_styleset',
		'open_pages_settings',
		'open_pages_settings_styles'
	);

	register_setting(  
		'open_pages_settings',
		'open_pages_settings'
	); 
}

function open_pages_settings_styles_output() {

}

function open_pages_settings_scheme() {
	$theme_settings = get_option('open_pages_settings');
	?>

	<select name="open_pages_settings[scheme]" id="scheme">
        <?php
        $options = array(
            'By the Fire',
            'At Sea',
            'Under a Tree'
        );
        
        foreach ( $options as $option ) : ?>
            <option value="<?php echo $option; ?>" <?php selected( $theme_settings['scheme'], $option ); ?>><?php echo $option; ?></option>
        <?php
        endforeach;
        ?>
    </select>

    <?php
}

function open_pages_settings_styleset() {
	$theme_settings = get_option('open_pages_settings');
	?>

	<select name="open_pages_settings[styleset]" id="styleset">
	    <?php
	    $options = array(
	        'Source',
	        'Josefin',
	        'Julius',
	        'Montez'
	    );
	    
	    foreach ( $options as $option ) : ?>
	        <option value="<?php echo $option; ?>" <?php selected( $theme_settings['styleset'], $option ); ?>><?php echo $option; ?></option>
	    <?php
	    endforeach;
	    ?>
    </select>

    <?php
}


/*-------------------------------------------------------------------------------------------*/
/* Comments */
/*-------------------------------------------------------------------------------------------*/
function open_pages_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<article>
		<div <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
			<header>
				<div class="comment-header">
					<div class="comment-author vcard">
						<div class="comment-author-name">
							
							<?php if ( $comment->comment_parent > 0 ) : ?>
								<span class="comment-author-said">
								<?php printf( __('%s replied:', 'open-pages'), '<cite class="fn">' . get_comment_author_link() . '</cite>' ); ?>
								</span>
							<?php else : ?>
								<span class="comment-author-said">
								<?php printf( __('%s said:', 'open-pages'), '<cite class="fn">' . get_comment_author_link() . '</cite>' ); ?>
								</span>
							<?php endif; ?>
						</div>
						
						<div class="gravatar">
							<?php
							if( !empty($comment->comment_author_email) ) : 
								echo get_avatar( get_comment_author_email(), '40' );
							endif; ?>
						</div>
					</div>
					
					<div class="meta comment-meta">
						<time datetime="<?php the_time('Y-m-d') ?>" pubdate>
							<a class="comment-date" href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
								<?php comment_time('M j'); ?><sup><?php comment_time('S'); ?></sup><?php comment_time('Y'); ?>, at
								<?php comment_time(' g:i A'); ?>
							</a>
						</time>
						<?php edit_comment_link(__('(Edit)', 'open-pages'),'  ','') ?>
						
						<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
					</div>
				</div>
			</header>
			
			<div class="comment-text">
				<?php comment_text(); ?>
				
				<?php if ($comment->comment_approved == '0') : ?>
					<em class="comment-moderation"><?php _e('Your comment is awaiting moderation.', 'open-pages') ?></em>
				<?php endif; ?>
			</div>
			
			<br class="clear" />
<?php
}

function open_pages_close_comment() {?>
	</div>
</article>
<?php
}

function open_pages_ping($comment, $args, $depth) {
  $GLOBALS['comment'] = $comment; ?>
   
  <li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
  <?php comment_author_link(); ?> &mdash; <?php comment_excerpt();
}


/*-------------------------------------------------------------------------------------------*/
/* Filter get_comment_link - http://thematictheme.com/2012/06/13/improved-separation-of-comments-and-pingbacks-in-thematic-1-0-1/ */
/*-------------------------------------------------------------------------------------------*/
function open_pages_get_comment_link( $link , $comment, $args ) {
	global  $wp_rewrite; 

	$args['type'] = 'comment';
	$args['page'] = get_page_of_comment( $comment->comment_ID, $args );
	
	if ( $args['per_page'] ) {
		if ( '' == $args['page'] )
			$args['page'] = ( !empty($in_comment_loop) ) ? get_query_var('cpage') : get_page_of_comment( $comment->comment_ID, $args );

		if ( $wp_rewrite->using_permalinks() )
			$link = user_trailingslashit( trailingslashit( get_permalink( $comment->comment_post_ID ) ) . 'comment-page-' . $args['page'], 'comment' );
		else
			$link = add_query_arg( 'cpage', $args['page'], get_permalink( $comment->comment_post_ID ) );
	} else {
		$link = get_permalink( $comment->comment_post_ID );
	}

	return $link . '#comment-' . $comment->comment_ID; 
}
add_filter( 'get_comment_link', 'open_pages_get_comment_link', 10, 3 );


/*-------------------------------------------------------------------------------------------*/
/* Blog Post Excerpt and Continue Reading Link */
/*-------------------------------------------------------------------------------------------*/
add_filter( 'excerpt_more', 'open_pages_excerpt_more' );

function open_pages_excerpt_more($more) {
	return ' &hellip;' . open_pages_continue_reading_link();
}

add_filter( 'get_the_excerpt', 'open_pages_custom_excerpt_more' );

function open_pages_custom_excerpt_more($output) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= open_pages_continue_reading_link();
	}
	return $output;
}

function open_pages_continue_reading_link() {
	$link = '</p><p class="continue-reading"><a href="'. get_permalink() . '">' . __('Continue reading', 'open-pages') . '</a>';
	
	return apply_filters('open_pages_continue_reading_link', $link);
}

function open_pages_excerpt_length_latest_posts() {
	return apply_filters('open_pages_excerpt_length_latest_posts', 30);
}

// http://wpengineer.com/1909/manage-multiple-excerpt-lengths/
function open_pages_excerpt($length_callback = '') {
	if ( function_exists($length_callback) ) {
		add_filter('excerpt_length', $length_callback);
	}
	
	$output = get_the_excerpt();
	$output = apply_filters('wptexturize', $output);
	$output = apply_filters('convert_chars', $output);
	$output = '<p>' . $output . '</p>';
	
	echo $output;
}


/*-------------------------------------------------------------------------------------------*/
/* Image Caption Shortcode */
/*-------------------------------------------------------------------------------------------*/
add_shortcode('wp_caption', 'open_pages_img_caption_shortcode');
add_shortcode('caption', 'open_pages_img_caption_shortcode');

function open_pages_img_caption_shortcode($attr, $content = null) {
	// Allow plugins/themes to override the default caption template.
	$output = apply_filters('img_caption_shortcode', '', $attr, $content);
	
	if ( $output != '' )
		return $output;
		
	if ( ! isset( $attr['caption'] ) ) {
		if ( preg_match( '#((?:<a [^>]+>\s*)?<img [^>]+>(?:\s*</a>)?)(.*)#is', $content, $matches ) ) {
			$content = $matches[1];
			$attr['caption'] = trim( $matches[2] );
		}
	}
	
	extract(shortcode_atts(array(
		'id'	=> '',
		'align'	=> 'alignnone',
		'width'	=> '',
		'caption' => ''
	), $attr));
	
	if ( 1 > (int) $width || empty($caption) )
		return $content;
	
	if ( $id ) $id = 'id="' . $id . '" ';
	
	return '<div ' . $id . 'class="' . esc_attr($align) . ' wp-caption-c" style="width: ' . ( (int) $width ) . 'px"><div class="wp-caption">'
	. do_shortcode( $content ) . '<p class="wp-caption-text">' . $caption . '</p></div></div>';
}


/*-------------------------------------------------------------------------------------------*/
/* Widgets */
/*-------------------------------------------------------------------------------------------*/
add_action( 'widgets_init', 'open_pages_widgets_init' );

function open_pages_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Widget Area 1', 'open-pages' ),
		'id' => 'widget-area-1',
		'description' => __( 'The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 2', 'open-pages' ),
		'id' => 'widget-area-2',
		'description' => __( 'The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 3', 'open-pages' ),
		'id' => 'widget-area-3',
		'description' => __( 'The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 4', 'open-pages' ),
		'id' => 'widget-area-4',
		'description' => __( 'The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 5', 'open-pages' ),
		'id' => 'widget-area-5',
		'description' => __( 'The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 6', 'open-pages' ),
		'id' => 'widget-area-6',
		'description' => __( 'Links will display as blocks across the width of the widget area. Use for lists of links. The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Widget Area 7', 'open-pages' ),
		'id' => 'widget-area-7',
		'description' => __( 'Links will display as blocks across the width of the widget area. Use for lists of links. The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 8', 'open-pages' ),
		'id' => 'widget-area-8',
		'description' => __( 'Links will display as blocks across the width of the widget area. Use for lists of links. The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 9', 'open-pages' ),
		'id' => 'widget-area-9',
		'description' => __( 'Links will display as blocks across the width of the widget area. Use for lists of links. The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Widget Area 10', 'open-pages' ),
		'id' => 'widget-area-10',
		'description' => __( 'Links will display as blocks across the width of the widget area. Use for lists of links. The placement of this widget area can be configured through SkyThemes Designer.', 'open-pages' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}