<?php
/* Define theme title */
define( 'SD_THEME_TITLE', 'Open Pages' );

/**
 * Define the prefixes and paths to the theme which uses SkyThemes Designer.
 * 
 * This may be a parent theme, child theme, or other location.
 * 
 * If defined using a parent theme, all templates and settings will be available
 * to all child themes using the theme, and will remain when switching child theme,
 * but lost when switching parent theme.
 * 
 * If defined using a child theme, all templates and settings will be lost when 
 * switching child theme.
 * 
 * To keep Designer templates and settings when changing themes, define a location
 * which is separate to a theme (eg. wp-content/designer/my-templates), then use the same
 * prefixes in the new theme
 */
define( 'SD_THEME_PREFIX', 'open_pages' );
define( 'SD_TEMPLATE_TYPES_PREFIX', 'open_pages' );

define( 'SD_THEME_DIR', get_template_directory() );
define( 'SD_THEME_URI', get_template_directory_uri() );

// set paths (relative to the theme root)
// no trailing slash
define( 'SD_GLOBAL_TEMPLATES_PATH', '/skythemes_designer' );
define( 'SD_USER_TEMPLATES_PATH', '/sd_user_templates' );

define( 'SD_BLOCKS_PATH', '/skythemes_designer/blocks' );
define( 'SD_LAYOUT_PATH', '/skythemes_designer/user/templates/layout' );
define( 'SD_LAYOUT_CSS_PATH', '/skythemes_designer/user/templates/layout_css' );

define( 'SD_TYPE_THEME_STYLESETS_PATH', '/skythemes_designer/presets/type' );
define( 'SD_TYPE_USER_STYLESETS_PATH', '/skythemes_designer/user/stylesets' );

define( 'SD_COLOUR_THEME_SCHEMES_PATH', '/skythemes_designer/presets/colour' );
define( 'SD_COLOUR_USER_SCHEMES_PATH', '/skythemes_designer/user/schemes' );

define( 'SD_TEMPLATE_OVERRIDES_PATH', '/skythemes_designer/user/templates/custom_css' );

// full path to the designer editor stylesheet (including file)
define( 'SD_EDITOR_STYLESHEET_PATH', '' );

/**
 * Set Layout Sections
 * Sets the sections that are availble to templates
 * Names must be different (even if only by case) from the id/class name of the element
 * and must only consist of characters that are valid css id's (apart from spaces, which will be converted to - )
 * Width should not include outside gutters
 */
add_filter('sd_layout_sections', 'new_sd_layout_sections');

function new_sd_layout_sections() {
	return array(
		"Header" => array(
			"global" => "true",
			"name position" => "right",
			"width" => "940",
			"columns" => "12",
			"gutter" => "20",
			"block width" => "grid",
			"ui color" => "dark"
		),
		"Page Header" => array(
			"global" => "true",
			"width" => "940",
			"columns" => "12",
			"gutter" => "20",
			"block width" => "grid",
			"ui color" => "dark"
		),
		"Full Width Content" => array(
			"width" => "940",
			"columns" => "12",
			"gutter" => "20",
			"block width" => "grid",
			"ui color" => "dark"
		),
		"Content" => array(
			"width" => "540",
			"columns" => "8",
			"gutter" => "20",
			"block width" => "540",
			"ui color" => "dark"
		),
		"Sidebar" => array(
			"global" => "true",
			"name position" => "right",
			"width" => "340",
			"columns" => "0",
			"gutter" => "20",
			"block width" => "340",
			"ui color" => "dark",
			"dependency" => "Content"
		),
		"Footer" => array(
			"global" => "true",
			"name position" => "right",
			"width" => "940",
			"columns" => "12",
			"gutter" => "20",
			"block width" => "grid",
			"ui color" => "dark"
		)
	);
}